"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StackingFaTag = exports.SimpleFaTag = exports.FaTagBase = void 0;
const TagDetector_1 = require("./TagDetector");
class FaTagBase {
    constructor(src, parsed, _kind) {
        this.kind = _kind;
        this.src = src;
    }
    static detectFaTag(str, pos, ignoreStyled) {
        // if not start with 0x3A(:) or 0x5B([) then returns null.
        if (str.charCodeAt(pos) !== 0x3A && str.charCodeAt(pos) !== 0x5B) {
            return null;
        }
        // slice from pos
        const source = str.slice(pos);
        // detect!
        let detected = (0, TagDetector_1._detectSimpleTag)(source, ignoreStyled);
        if (detected !== null) {
            return new SimpleFaTag(detected.tag, detected.parsed);
        }
        else {
            detected = (0, TagDetector_1._detectStackingTag)(source, ignoreStyled);
            if (detected !== null) {
                return new StackingFaTag(detected.tag, detected.parsed);
            }
        }
        return null;
    }
}
exports.FaTagBase = FaTagBase;
class SimpleFaTag extends FaTagBase {
    constructor(tag, parsed) {
        super(tag, parsed, "simple");
        this.icons = [];
        this.styles = [];
        this._setParsed(parsed);
    }
    get hasStyle() {
        return this.styles.length !== 0;
    }
    getIconsAsString() {
        return `${this.icons.join(' ')}`;
    }
    getStylesAsString(removeComma) {
        return removeComma ?
            `${this.styles.join(' ')}` :
            `${this.styles.map(style => '.' + style).join(' ')}`;
    }
    toString() {
        const icons = this.getIconsAsString();
        const styles = this.getStylesAsString(false);
        return !this.hasStyle ?
            `:${icons}:` : `[:${icons}:]{${styles}}`;
    }
    _setParsed(parsed) {
        this.icons.push(...parsed.faClasses
            .split(' ')
            .filter((item) => item !== ''));
        if (parsed.styleClasses !== null) {
            this.styles.push(...parsed.styleClasses
                .split(' ')
                .filter(item => item != '')
                .map(styleCalss => styleCalss.replace('.', '')));
        }
    }
}
exports.SimpleFaTag = SimpleFaTag;
class StackingFaTag extends FaTagBase {
    constructor(src, parsed) {
        super(src, parsed, "stacking");
        this.children = [];
        this._setParsed(parsed);
    }
    toString() {
        const joinedChildren = this.children
            .map(child => child.toString())
            .join(' ');
        return `[${joinedChildren}]`;
    }
    _setParsed(parsed) {
        this.children.push(...parsed.map(item => new SimpleFaTag(null, item)));
    }
}
exports.StackingFaTag = StackingFaTag;
