"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FaTagListTokenReplacer = void 0;
const FaTag_1 = require("./FaTag");
class FaTagListTokenReplacer {
    constructor(state, marker) {
        this._state = state;
        this._marker = marker;
    }
    get isFaTagList() {
        const startToken = this._state.tokens[this._marker.start];
        if (startToken.tag !== 'ul') {
            return false;
        }
        const allStartWithFaItem = this.contents.every(item => {
            const detected = FaTag_1.FaTagBase.detectFaTag(item.content, 0, false);
            return detected?.kind === 'simple';
        });
        return allStartWithFaItem;
    }
    get contents() {
        if (this._marker.listItemContents != null) {
            return this._marker.listItemContents;
        }
        const contents = this._state.tokens
            .slice(this._marker.start)
            .filter(token => token.type === 'inline');
        this._marker.listItemContents = contents;
        return contents;
    }
    replace() {
        if (this.isFaTagList) {
            this._addUlClass('fa-ul');
        }
    }
    _addUlClass(className) {
        const startToken = this._state.tokens[this._marker.start];
        if (startToken.tag === 'ul') {
            startToken.attrPush(['class', className]);
        }
        this.contents.forEach(item => {
            const faTag = FaTag_1.FaTagBase.detectFaTag(item.content, 0, false);
            faTag.styles.push("fa-li");
            item.content = item.content.replace(faTag.src, faTag.toString());
        });
    }
}
exports.FaTagListTokenReplacer = FaTagListTokenReplacer;
