"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StackingTokenizer = exports.FaTagTokenizer = exports.FaTokenizerBase = void 0;
const FaTag_1 = require("./FaTag");
class FaTokenizerBase {
    constructor(stateInline, silent, detectedTag) {
        this._stateInline = stateInline;
        this._silent = silent;
        this._faTag = detectedTag;
    }
    _pushStackingTag(stackingTag) {
        const stackingIconTag = this._stateInline.push('fa_icon_stacking_open', 'span', 1);
        stackingIconTag.attrPush(['class', "fa-stack"]);
        for (const fatag of stackingTag.children) {
            this._pushFaTag(fatag);
        }
        this._stateInline.push('fa_icon_stacking_close', 'span', -1);
    }
    _pushFaTag(fatag) {
        if (fatag.hasStyle) {
            const iconTag = this._stateInline.push('fa_icon_style_open', 'span', 1);
            iconTag.attrPush(['class', fatag.getStylesAsString(true)]);
        }
        const iconTag = this._stateInline.push('fa_icon_open', 'i', 1);
        iconTag.attrPush(['class', fatag.getIconsAsString()]);
        this._stateInline.push('fa_icon_close', 'i', -1);
        if (fatag.hasStyle) {
            this._stateInline.push('fa_icon_style_close', 'span', -1);
        }
    }
    run() {
        this._stateInline.pos = Math.min(this._stateInline.posMax, this._stateInline.pos + this._faTag.src.length);
        if (!this._silent) {
            this._tokenize();
        }
    }
    static createTokenizer(state, silent, option) {
        const faTag = FaTag_1.FaTagBase.detectFaTag(state.src, state.pos, option.ignoreStyled ?? false);
        var tokenizer = null;
        if (faTag != null) {
            switch (faTag.kind) {
                case "simple":
                    tokenizer = new FaTagTokenizer(state, silent, faTag);
                    break;
                case "stacking":
                    tokenizer = new StackingTokenizer(state, silent, faTag);
                    break;
            }
        }
        return tokenizer;
    }
}
exports.FaTokenizerBase = FaTokenizerBase;
class FaTagTokenizer extends FaTokenizerBase {
    _tokenize() {
        this._pushFaTag(this._faTag);
    }
}
exports.FaTagTokenizer = FaTagTokenizer;
class StackingTokenizer extends FaTokenizerBase {
    _tokenize() {
        this._pushStackingTag(this._faTag);
    }
}
exports.StackingTokenizer = StackingTokenizer;
